# Delightful Forgejo

[![delightful](https://codeberg.org/teaserbot-labs/delightful/raw/branch/main/assets/delightful-badge.svg)](https://codeberg.org/teaserbot-labs/delightful)

A curated list of delightful [Forgejo](https://forgejo.org/)-related projects and resources.

<!-- Everyone is invited to contribute. To do so, please read guidelines at: https://codeberg.org/teaserbot-labs/delightful -->


## Contents
- [Official resources](#official-resources)
- [Documentation](#documentation)
- [Public instances](#public-instances)
- [Packaging](#packaging)
- [Infrastructure as Code](#infrastructure-as-code)
- [Monitoring](#monitoring)
- [Clients](#clients)
	- [Mobile](#mobile)
	- [Command-line](#command-line)
- [Tools](#tools)
	- [Bots](#bots)
- [Maintainers](#maintainers)
- [Contributors](#contributors)
- [License](#license)


## Official resources
Resources maintained as part of the primary Forgejo project.
- [Forgejo website](https://forgejo.org/)
- [Forgejo documentation](https://forgejo.org/docs/latest/)
- [Releases](https://forgejo.org/releases) ([RSS feed](https://forgejo.org/releases/rss.xml); [Release notes](https://codeberg.org/forgejo/forgejo/src/branch/forgejo/RELEASE-NOTES.md))
- [Container images](https://codeberg.org/forgejo/-/packages/container/forgejo/versions)
- [Forgejo Mastodon account](https://floss.social/@forgejo)
- [Forgejo identity proofs (Keyoxide)](https://keyoxide.org/contact@forgejo.org)


## Documentation

In addition to Forgejo's official documentation, the following resources may be useful.

- [Codeberg documentation](https://docs.codeberg.org/) - contains some Codeberg-specific parts but is mostly applicable to every Forgejo instance.
- [Gitea documentation](https://docs.gitea.io/) - mostly applicable to Forgejo as well as Gitea.
- [UberLab installation guides](https://lab.uberspace.de/guide_forgejo/) - Forgejo installation guide for [Uberspace](https://uberspace.de/).

## Public instances
Forgejo instances with open registration.
- [Codeberg](https://codeberg.org) - free and open *for FOSS projects only*, run by a German non-profit organization. Also provides hosted Woodpecker (CI) and Weblate (localisation).


## Packaging
Platform-specific packages to easily install and update Forgejo on your system. These are generally maintained either by distro packagers or by community volunteers.

<a href="https://repology.org/project/forgejo/versions">
	<img src="https://repology.org/badge/vertical-allrepos/forgejo.svg" alt="Packaging status" align="right" />
</a>

Also see [forgejo package versions on Repology](https://repology.org/project/forgejo/versions).
- **Alpine**
  - [unofficial `forgejo-alpine` package](https://codeberg.org/Eragon/forgejo-alpine)
- **Arch Linux**
	- [Arch community `forgejo` package](https://archlinux.org/packages/community/x86_64/forgejo/)
	- [AUR `forgejo-git` package](https://aur.archlinux.org/packages/forgejo-git)
- **Debian/Ubuntu**
	- [Unofficial packages](https://codeberg.org/crystal/forgejo-deb)
- **Fedora**
	- [RPM copr repo](https://copr.fedorainfracloud.org/coprs/nalika/gitea/)
- **FreeBSD**
	- [ports tree patch](https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=269065) - A patch to add Forgejo to the FreeBSD ports tree, should eventually be added to the official ports tree
- **Gentoo**
	- [Gentoo GURU `www-apps/forgejo` package](https://gitweb.gentoo.org/repo/proj/guru.git/tree/www-apps/forgejo)
- **Kubernetes**
	- [Helm chart](https://codeberg.org/forgejo-contrib/forgejo-helm) - Helm chart for Forgejo, forked from the official Gitea helm chart
	- [c4k-forgejo](https://repo.prod.meissa.de/meissa/c4k-forgejo) - Convention 4 Kubernetes, generates a kubernetes manifest for Forgejo including backup & monitoring.
- **NixOS**
	- [NixOS unstable](https://github.com/NixOS/nixpkgs/blob/nixos-unstable/pkgs/applications/version-management/forgejo/default.nix)
- **YunoHost**
	- [YunoHost package](https://github.com/YunoHost-Apps/forgejo_ynh) - install Forgejo quickly and simply on a YunoHost server

## Infrastructure as Code
- [Ansible playbook](https://lab.enough.community/main/infrastructure/-/tree/master/playbooks/forgejo) - Deploy Forgejo & Woodpecker, depends on related [Enough Community](https://enough.community) playbooks.
- [Terraform & Ansible playbook](https://forgejo.dev/forgejo.dev/infrastructure-as-code/) - Deploy Forgejo, Minio, Nginx & Woodpecker in the cloud via [Docker Compose](https://docs.docker.com/compose/), depends on related [geerlingguy](https://github.com/geerlingguy) playbooks.

## Monitoring
- [Monitoring plugin to check Forgejo instance upgrade status](https://gitea.zionetrix.net/bn8/check_forgejo_upgrade) has the sources and is published in the [Icinga exchange repository](https://exchange.icinga.com/brenard/check_forgejo_upgrade).

## Clients

### Mobile
- [GitNex](https://gitnex.com/) ([repo](https://codeberg.org/gitnex/GitNex)) - Android client for Forgejo and Gitea (`Android – GPL`)
- [GitTouch](https://github.com/git-touch/git-touch) - Mobile client for Forgejo, Gitea, GitHub, GitLab, Bitbucket  (`Android, iOS – Apache`)

### Command-line
- [tea](https://gitea.com/gitea/tea) - the official Gitea CLI client, works with Forgejo (`cross-platform – MIT`)


## Tools

### Bots
- [gitcat](https://git.mastodont.cat/spla/gitcat) - Python script that allows sign-up to a Forgejo instance to all local users of a Mastodon server. (`Python - GPLv3`)
- [Renovate](https://docs.renovatebot.com/modules/platform/gitea/#gitea-and-forgejo) - Dependency update tool (similar to dependabot) with Forgejo support. (`TypeScript - AGPLv3`)

### Scripts
- [github2gitea/github2forgejo](https://github.com/maxkratz/github2gitea-mirror) - Bash script that creates mirrors for various GitHub resources like orgs, users and starred repos (incl. private repos). (`Bash - AGPLv3`)


## Maintainers

If you have questions or feedback regarding this list, then please create
an [Issue](https://codeberg.org/forgejo-contrib/delightful-forgejo/issues) in our tracker, and optionally `@mention` one or more of our maintainers:

- [`@caesar`](https://codeberg.org/caesar)
- [`@crystal`](https://codeberg.org/crystal)
- [`@Ryuno-Ki`](https://codeberg.org/Ryuno-Ki)


## Contributors

With delight we present you some of our [delightful contributors](delightful-contributors.md) (please [add yourself](https://codeberg.org/teaserbot-labs/delightful/src/branch/master/delight-us.md#attribution-of-contributors) if you are missing).


## License

[![CC0](https://mirrors.creativecommons.org/presskit/buttons/88x31/svg/cc-zero.svg)](https://creativecommons.org/publicdomain/zero/1.0/)

To the extent possible under law, the [maintainers](#maintainers) and other [contributors](delightful-contributors.md) have waived all copyright and related or neighboring rights to this work.
